====
News
====

Announcements
=============

2017-07-07
----------

@Flimm: sorl-thumbnail was welcomed into the `Jazzband organization and project
<https://jazzband.co/>`__. Jazzband is open to all, and any member of Jazzband
can contribute directly to sorl-thumbnail's GitHub repo. We hope this will
encourage more open source programmers to contribute. Thank you @mariocesar for
taking this step and for the years of effort in this project.

@Flimm: As part of joining Jazzband, the GitHub repo has been moved to
https://github.com/jazzband/sorl-thumbnail

2013-11-12
----------

@mariocesar: We have a new team of mantainers for sorl-thumbnail. I wan't to encourage
all developers that have fixes, forks and new features to talk in the irc channel of
the project. irc://freenode.net/#sorl-thumbnail


2013-11-09
----------

@nikko: Unfortunately I no longer work with Django so my motivation to keep developing
for sorl-thumbnail is very low. If you are interested in taking over this
project please send an email to mikko@aino.se explaing why you are the perfect
fit for owning this project.

.. include:: ../CHANGES.rst
